@@ -1,3 +1,13 @@
+##
+# name:      Module::Install::Admin::PMC
+# abstract:  Author Support for Perl Compilation (.pmc)
+# author:    Ingy döt Net <ingy@ingy.net>
+# license:   perl
+# copyright: 2006, 2011
+# see:
+# - Module::Install
+# - Module::Compile
+
 package Module::Install::Admin::PMC;
 
 use strict;
@@ -6,8 +16,8 @@ use File::Basename ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.61';
-	@ISA     = qw{Module::Install::Base};
+    $VERSION = '0.61';
+    @ISA     = qw{Module::Install::Base};
 }
 
 # Admin support for author side pmc management
@@ -55,46 +65,3 @@ pmc ::
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Module::Install::Admin::PMC - Author Support for Perl Compilation (.pmc)
-
-=head1 SYNOPSIS
-
-  To be completed
-
-=head1 DESCRIPTION
-
-  To be completed
-
-=head1 COMMANDS
-
-To be completed
-
-=head1 TO DO
-
-To be completed
-
-=head1 SEE ALSO
-
-L<Module::Install>, L<Module::Compile>
-
-=head1 AUTHORS
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
